@@ -51,6 +51,8 @@ libwacom_class_string_to_enum(const char *class)
 		return WCLASS_INTUOS3;
 	if (strcmp(class, "Intuos4") == 0)
 		return WCLASS_INTUOS4;
+	if (strcmp(class, "Intuos5") == 0)
+		return WCLASS_INTUOS5;
 	if (strcmp(class, "Cintiq") == 0)
 		return WCLASS_CINTIQ;
 	if (strcmp(class, "Bamboo") == 0)
@@ -466,4 +468,29 @@ libwacom_database_destroy(WacomDeviceDatabase *db)
 	g_free (db);
 }
 
+WacomDevice**
+libwacom_list_devices_from_database(WacomDeviceDatabase *db, WacomError *error)
+{
+	GList *cur, *devices;
+	WacomDevice **list, **p;
+
+	if (!db) {
+		libwacom_error_set(error, WERROR_INVALID_DB, "db is NULL");
+		return NULL;
+	}
+
+	devices =  g_hash_table_get_values (db->device_ht);
+	list = calloc (g_list_length (devices) + 1, sizeof (WacomDevice *));
+	if (!list) {
+		libwacom_error_set(error, WERROR_BAD_ALLOC, "Memory allocation failed");
+		return NULL;
+	}
+
+	for (p = list, cur = devices; cur; cur = g_list_next (cur))
+		*p++ = (WacomDevice *) cur->data;
+	g_list_free (devices);
+
+	return list;
+}
+
 /* vim: set noexpandtab tabstop=8 shiftwidth=8: */
