@@ -48,8 +48,8 @@ int main(int argc, char **argv)
     device = libwacom_new_from_usbid(db, 0x56a, 0x00bc, NULL);
     assert(device);
 
-    str = libwacom_get_vendor(device);
-    assert(strcmp(str, "Wacom") == 0);
+    str = libwacom_get_name(device);
+    assert(strcmp(str, "Wacom Intuos4 WL") == 0);
     assert(libwacom_get_class(device) == WCLASS_INTUOS4);
     assert(libwacom_get_vendor_id(device) == 0x56a);
     assert(libwacom_get_product_id(device) == 0xbc);
@@ -60,13 +60,39 @@ int main(int argc, char **argv)
     assert(!libwacom_has_touch(device));
     assert(libwacom_has_ring(device));
     assert(!libwacom_has_ring2(device));
-    assert(!libwacom_has_vstrip(device));
-    assert(!libwacom_has_hstrip(device));
+    assert(libwacom_get_num_strips(device) == 0);
     assert(!libwacom_is_builtin(device));
-    assert(libwacom_get_width(device) == 9);
-    assert(libwacom_get_height(device) == 6);
+    assert(libwacom_get_width(device) == 8);
+    assert(libwacom_get_height(device) == 5);
 
     libwacom_destroy(device);
+
+    device = libwacom_new_from_usbid(db, 0x56a, 0x00b9, NULL);
+    assert(device);
+
+    assert(libwacom_get_button_flag(device, 'A') & WACOM_BUTTON_RING_MODESWITCH);
+    assert(libwacom_get_button_flag(device, 'I') & WACOM_BUTTON_OLED);
+    assert(libwacom_get_button_flag(device, 'J') == WACOM_BUTTON_NONE);
+    assert(libwacom_get_ring_num_modes(device) == 4);
+
+    libwacom_destroy(device);
+
+    device = libwacom_new_from_usbid(db, 0x56a, 0x00f4, NULL);
+    assert(device);
+
+    assert(libwacom_get_ring_num_modes(device) == 3);
+    assert(libwacom_get_ring2_num_modes(device) == 3);
+
+    libwacom_destroy(device);
+
+    device = libwacom_new_from_usbid(db, 0x056a, 0x00cc, NULL);
+    assert(libwacom_get_num_strips(device) == 2);
+    libwacom_destroy(device);
+
+    device = libwacom_new_from_name(db, "Wacom Serial Tablet WACf004", NULL);
+    assert(device);
+    assert(libwacom_is_builtin(device));
+
     libwacom_database_destroy (db);
 
     return 0;
